@@ -5,7 +5,44 @@
              MultiParamTypeClasses, DeriveDataTypeable,
              ScopedTypeVariables, PatternGuards #-}
 
-module Happstack.Data.Xml.Base where
+module Happstack.Data.Xml.Base 
+    ( Element(..)
+    , insEl
+    , fromXml
+    , Other(..)
+    , toPublicXml
+    , Rigidity(..)
+    , XmlD(..)
+    , Xml(..)
+    , xmlProxy
+    , defaultToXml
+    , transparentToXml
+    , transparentReadXml
+    , transparentXml
+    , defaultReadXml
+    , defaultReadXml'
+    , readXmlWith
+    , readVersionedElement
+    , isTheAttr
+    , getAttr
+    , versionAttr
+    , typeAttr
+    , readElement
+    , aConstrFromElements
+    , constrFromElementsNoRootDefault
+    , constrFromElements
+    , getXmls
+    , putXmls
+    , readMXml
+    , readMXmlNoRootDefault
+    , xmlAttr
+    , xmlShowCDatas
+    , xmlShowCData
+    , xmlCDataLists
+    , xmlCDataList
+    , noCommas
+    , typeNotValue
+    ) where
 
 import Control.Monad.Identity
 import Control.Monad.State
@@ -20,9 +57,22 @@ import Happstack.Data.Default
 import Happstack.Data.DeriveAll
 import Happstack.Data.Migrate
 import Happstack.Data.Normalize
-import Happstack.Util.TH
 import Language.Haskell.TH
 
+-- | Version of 'instanceD' that takes in a Q [Dec] instead of a [Q Dec]
+-- and filters out signatures from the list of declarations
+instanceD' :: CxtQ -> TypeQ -> Q [Dec] -> DecQ
+instanceD' ctxt ty decs =
+    do decs' <- decs
+       let decs'' = filter (not . isSigD) decs'
+       instanceD ctxt ty (map return decs'')
+
+-- | Returns true if the Dec matches a SigD constructor
+isSigD :: Dec -> Bool
+isSigD (SigD _ _) = True
+isSigD _ = False
+
+
 {-| Element recursively represents XML data.  
     Elem n elems -> XML element with name n and described by elems.  Note that elems contains sub-elements as well as the attributes or literal data of the element.
     CData d -> Literal string data
